@@ -16,7 +16,7 @@ parser.add_argument(
 )
 parser.add_argument(
     "--noexplain",
-    "-e",
+    "-E",
     action="store_true",
     help="a wrong answer won't be explained",
 )
@@ -106,7 +106,7 @@ class Game:
         self.question = question
         self.quiet = args.quiet
         self.repeat = args.repeat
-        self.explain = not args.noexplain and not self.repeat
+        self.explain = not (args.quiet or args.noexplain or self.repeat)
         self._reset()
 
     def _reset(self):
@@ -142,12 +142,12 @@ class Game:
                 self.raw_answers.append((time(), correct))
                 if correct:
                     if not self.quiet:
-                        print("correct!")
+                        print("\tcorrect!")
                     self.score += 1
                     self.streak += 1
                 else:
                     if not self.quiet:
-                        print(f"wrong... {explanation if should_explain else ''}")
+                        print(f"\twrong... {explanation if should_explain else ''}")
                     self.mistakes += 1
                     self.streak = 0
 
@@ -157,8 +157,13 @@ class Game:
         else:
             t = int(time() - self.starttime)
 
-        print(f"time:\t{t//59} mins {t%60} seconds")
-        print(f"score:\t{self.score}/{self.score + self.mistakes}")
+        count = self.score + self.mistakes
+        avg = t // count
+
+        print(f"time:\t{t//60} mins {t%60} seconds")
+        print(f"avg:\t{avg // 60} mins {avg%60} seconds")
+        print(f"score:\t{self.score}/{count}")
+        print(f"percent:\t{self.score/count*100:.2f}%")
 
     def _done(self):
         return (
@@ -169,6 +174,16 @@ class Game:
             or (self.gamemode == "c" and self.param == self.streak)
         )
 
+    def get_flags(self):
+        ans = ""
+        if self.quiet:
+            ans += "q"
+        if self.repeat:
+            ans += "r"
+        if not self.explain:
+            ans += "E"
+        return ans
+
     def save_raw(self, file="./stats.json"):
         import json
         from pathlib import Path
@@ -177,6 +192,7 @@ class Game:
             "starttime": self.starttime,
             "gamemode": self.gamemode,
             "param": self.param,
+            "flags": self.get_flags(),
             "answers": self.raw_answers,
         }
 
